@@ -4,7 +4,6 @@ __all__ = ['Deque']
 
 __metaclass__ = type
 
-import collections
 import redis.exceptions as redispy_exception
 
 from ooredis.key.base_key import BaseKey
@@ -292,15 +291,91 @@ class Deque(BaseKey):
         except redispy_exception.ResponseError:
             raise TypeError
 
+    
+    def __delitem__(self, index):
+        """
+        删除列表中给定 index 上的值。
 
-    def __delitem__(self, key):
-        raise Exception 
+        Args:
+            index ：可以是单个 key ，也可以是一个表示范围的 slice 。
+            item
+
+        Time:
+            O(N)
+
+        Returns:
+            None
+
+        Raises:
+            TypeError: 尝试对非 list 类型的 key 进行操作时抛出。
+        """
+        # TODO: 这个实现带有竞争条件
+        all_python_item = list(self)
+        del all_python_item[index]
+        self.delete()
+        if all_python_item != []:
+            self.extend(all_python_item)
+        """
+        # del self[index]
+        # ...
+
+        # del self[:]
+        if key.start is None and key.stop is None:
+            self.delete()
+
+        # del self[i:]
+        if key.start is not None and key.stop is None:
+            self._client.ltrim(self.name, 0, key.start-1)
+
+        # del self[:j]
+        if key.start is None and key.stop is not None:
+            self._client.ltrim(self.name, key.stop, -1)
+
+        # del self[i:j]
+        # ...
+        """
 
 
     def __getitem__(self, index):
-        all_item = list(self)
-        return all_item[index]
+        """
+        返回列表中给定 index 上的值。
+
+        Args:
+            index ：可以是单个 key ，也可以是一个表示范围的 slice 。
+            item
+
+        Time:
+            O(N)
+
+        Returns:
+            None
+
+        Raises:
+            TypeError: 尝试对非 list 类型的 key 进行操作时抛出。
+        """
+        return list(self)[index]
 
 
     def __setitem__(self, index, item):
-        raise Exception
+        """
+        将列表中给定 index 上的值设置为 item 。
+
+        Args:
+            index ：可以是单个 key ，也可以是一个表示范围的 slice 。
+            item
+
+        Time:
+            O(N)
+
+        Returns:
+            None
+
+        Raises:
+            TypeError: 尝试对非 list 类型的 key 进行操作时抛出。
+        """
+        # TODO: 这个实现带有竞争条件
+        all_python_item = list(self)
+        all_python_item[index] = item
+        self.delete()
+        if all_python_item != []:
+            self.extend(all_python_item)
