@@ -4,18 +4,15 @@ __all__ = ['String']
 
 __metaclass__ = type
 
-from functools import wraps
 from ooredis.key.base_key import BaseKey
 from ooredis.const import REDIS_TYPE
 from ooredis.key.helper import format_key, wrap_exception
 
-
 def raise_when_set_wrong_type(func):
     """
     set/setex/setnx 命令可以无视类型进行设置的命令，为了保证类型的限制，
     ooredis 对一个非 string 类型进行 set/setex/setnx 将引发 TypeError 异常。
     """
-    @wraps(func)
     def wrapper(*args, **kwargs):
         self = args[0]
         if self.exists and \
@@ -24,7 +21,6 @@ def raise_when_set_wrong_type(func):
         return func(*args, **kwargs)
     return wrapper
 
-
 class String(BaseKey):
 
     """
